translate.convert.po2tiki.po2tiki

Package translate :: Package convert :: Module po2tiki :: Class po2tiki |
[hide private]
[frames] | no frames]

# Class po2tiki

source code

Instance Methods | [hide private]
convertstore(self, thepofile) Converts a given (parsed) po file to a tiki file. | source code

Method Details | [hide private]

### convertstore(self, thepofile) | source code
Converts a given (parsed) po file to a tiki file. Parameters: `thepofile` - a pofile pre-loaded with input data